Update tracking issue number of future-incompatibility lint `unstable_syntax_pre_expansion`
diff --git a/tests/ui/cfg/cfg-false-feature.stderr b/tests/ui/cfg/cfg-false-feature.stderr
index 542aeaf..25c2213 100644
--- a/tests/ui/cfg/cfg-false-feature.stderr
+++ b/tests/ui/cfg/cfg-false-feature.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(box_patterns)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: trait aliases are experimental
   --> $DIR/cfg-false-feature.rs:12:1
@@ -20,7 +20,7 @@
    = help: add `#![feature(trait_alias)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 2 warnings emitted
 
diff --git a/tests/ui/feature-gates/soft-feature-gate-auto_traits.stderr b/tests/ui/feature-gates/soft-feature-gate-auto_traits.stderr
index 20811aa..899db50 100644
--- a/tests/ui/feature-gates/soft-feature-gate-auto_traits.stderr
+++ b/tests/ui/feature-gates/soft-feature-gate-auto_traits.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(auto_traits)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 1 warning emitted
 
diff --git a/tests/ui/feature-gates/soft-feature-gate-box_patterns.stderr b/tests/ui/feature-gates/soft-feature-gate-box_patterns.stderr
index a8399b5..2a19141 100644
--- a/tests/ui/feature-gates/soft-feature-gate-box_patterns.stderr
+++ b/tests/ui/feature-gates/soft-feature-gate-box_patterns.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(box_patterns)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: box pattern syntax is experimental
   --> $DIR/soft-feature-gate-box_patterns.rs:14:18
@@ -20,7 +20,7 @@
    = help: add `#![feature(box_patterns)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 2 warnings emitted
 
diff --git a/tests/ui/feature-gates/soft-feature-gate-decl_macro.stderr b/tests/ui/feature-gates/soft-feature-gate-decl_macro.stderr
index 7152162..1162c9e 100644
--- a/tests/ui/feature-gates/soft-feature-gate-decl_macro.stderr
+++ b/tests/ui/feature-gates/soft-feature-gate-decl_macro.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(decl_macro)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: `macro` is experimental
   --> $DIR/soft-feature-gate-decl_macro.rs:13:1
@@ -20,7 +20,7 @@
    = help: add `#![feature(decl_macro)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 2 warnings emitted
 
diff --git a/tests/ui/feature-gates/soft-feature-gate-negative_impls.stderr b/tests/ui/feature-gates/soft-feature-gate-negative_impls.stderr
index 35e125c..361244a 100644
--- a/tests/ui/feature-gates/soft-feature-gate-negative_impls.stderr
+++ b/tests/ui/feature-gates/soft-feature-gate-negative_impls.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(negative_impls)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 1 warning emitted
 
diff --git a/tests/ui/feature-gates/soft-feature-gate-trait_alias.stderr b/tests/ui/feature-gates/soft-feature-gate-trait_alias.stderr
index e50d4c3..975b9df 100644
--- a/tests/ui/feature-gates/soft-feature-gate-trait_alias.stderr
+++ b/tests/ui/feature-gates/soft-feature-gate-trait_alias.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(trait_alias)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: trait aliases are experimental
   --> $DIR/soft-feature-gate-trait_alias.rs:13:1
@@ -20,7 +20,7 @@
    = help: add `#![feature(trait_alias)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 2 warnings emitted
 
diff --git a/tests/ui/feature-gates/soft-feature-gate-try_blocks.stderr b/tests/ui/feature-gates/soft-feature-gate-try_blocks.stderr
index 2b20f40..360f517 100644
--- a/tests/ui/feature-gates/soft-feature-gate-try_blocks.stderr
+++ b/tests/ui/feature-gates/soft-feature-gate-try_blocks.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(try_blocks)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 1 warning emitted
 
diff --git a/tests/ui/feature-gates/soft-syntax-gates-without-errors.stderr b/tests/ui/feature-gates/soft-syntax-gates-without-errors.stderr
index 817e285..112245b 100644
--- a/tests/ui/feature-gates/soft-syntax-gates-without-errors.stderr
+++ b/tests/ui/feature-gates/soft-syntax-gates-without-errors.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(decl_macro)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: `macro` is experimental
   --> $DIR/soft-syntax-gates-without-errors.rs:21:5
@@ -20,7 +20,7 @@
    = help: add `#![feature(decl_macro)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 2 warnings emitted
 
diff --git a/tests/ui/or-patterns/or-patterns-syntactic-pass.stderr b/tests/ui/or-patterns/or-patterns-syntactic-pass.stderr
index a755342..828a395 100644
--- a/tests/ui/or-patterns/or-patterns-syntactic-pass.stderr
+++ b/tests/ui/or-patterns/or-patterns-syntactic-pass.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(box_patterns)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 1 warning emitted
 
diff --git a/tests/ui/pattern/rest-pat-syntactic.stderr b/tests/ui/pattern/rest-pat-syntactic.stderr
index 4de2730..41bbfd6 100644
--- a/tests/ui/pattern/rest-pat-syntactic.stderr
+++ b/tests/ui/pattern/rest-pat-syntactic.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(box_patterns)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: box pattern syntax is experimental
   --> $DIR/rest-pat-syntactic.rs:62:17
@@ -20,7 +20,7 @@
    = help: add `#![feature(box_patterns)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 2 warnings emitted
 
diff --git a/tests/ui/specialization/soft-feature-gate-specialization.default.stderr b/tests/ui/specialization/soft-feature-gate-specialization.default.stderr
index f596109..de79600 100644
--- a/tests/ui/specialization/soft-feature-gate-specialization.default.stderr
+++ b/tests/ui/specialization/soft-feature-gate-specialization.default.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(specialization)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: specialization is experimental
   --> $DIR/soft-feature-gate-specialization.rs:24:5
@@ -20,7 +20,7 @@
    = help: add `#![feature(specialization)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: specialization is experimental
   --> $DIR/soft-feature-gate-specialization.rs:40:1
@@ -32,7 +32,7 @@
    = help: add `#![feature(specialization)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: specialization is experimental
   --> $DIR/soft-feature-gate-specialization.rs:27:5
@@ -44,7 +44,7 @@
    = help: add `#![feature(specialization)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: specialization is experimental
   --> $DIR/soft-feature-gate-specialization.rs:35:1
@@ -56,7 +56,7 @@
    = help: add `#![feature(specialization)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 5 warnings emitted
 
diff --git a/tests/ui/specialization/soft-feature-gate-specialization.min.stderr b/tests/ui/specialization/soft-feature-gate-specialization.min.stderr
index aa4ce0c..d533748 100644
--- a/tests/ui/specialization/soft-feature-gate-specialization.min.stderr
+++ b/tests/ui/specialization/soft-feature-gate-specialization.min.stderr
@@ -8,7 +8,7 @@
    = help: add `#![feature(specialization)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: specialization is experimental
   --> $DIR/soft-feature-gate-specialization.rs:24:5
@@ -20,7 +20,7 @@
    = help: add `#![feature(specialization)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: specialization is experimental
   --> $DIR/soft-feature-gate-specialization.rs:40:1
@@ -32,7 +32,7 @@
    = help: add `#![feature(specialization)]` to the crate attributes to enable
    = note: this compiler was built on YYYY-MM-DD; consider upgrading it if it is out of date
    = warning: unstable syntax can change at any point in the future, causing a hard error!
-   = note: for more information, see issue #65860 <https://github.com/rust-lang/rust/issues/65860>
+   = note: for more information, see issue #154045 <https://github.com/rust-lang/rust/issues/154045>
 
 warning: 3 warnings emitted
diff --git a/compiler/rustc_lint_defs/src/builtin.rs b/compiler/rustc_lint_defs/src/builtin.rs
index b3cac5a..4aff294 100644
--- a/compiler/rustc_lint_defs/src/builtin.rs
+++ b/compiler/rustc_lint_defs/src/builtin.rs
@@ -3158,7 +3158,7 @@
     /// ### Example
     ///
     /// ```rust
-    /// #[cfg(FALSE)]
+    /// #[cfg(feature = "nightly")]
     /// macro foo() {}
     /// ```
     ///
@@ -3182,22 +3182,22 @@
     ///    ( $($tokens:tt)* ) => { $($tokens)* }
     /// }
     ///
-    /// #[cfg(FALSE)]
+    /// #[cfg(feature = "nightly")]
     /// identity! {
     ///    macro foo() {}
     /// }
     /// ```
     ///
     /// This is a [future-incompatible] lint to transition this
     /// to a hard error in the future. See [issue #65860] for more details.
     ///
-    /// [issue #65860]: https://github.com/rust-lang/rust/issues/65860
+    /// [issue #154045]: https://github.com/rust-lang/rust/issues/154045
     /// [future-incompatible]: ../index.md#future-incompatible-lints
     pub UNSTABLE_SYNTAX_PRE_EXPANSION,
     Warn,
     "unstable syntax can change at any point in the future, causing a hard error!",
     @future_incompatible = FutureIncompatibleInfo {
-        reason: fcw!(FutureReleaseError #65860),
+        reason: fcw!(FutureReleaseError #154045),
     };
 }
 
@@ -3182,22 +3182,22 @@
     ///
     /// This is a [future-incompatible] lint to transition this
-    /// to a hard error in the future. See [issue #65860] for more details.
+    /// to a hard error in the future. See [issue #154045] for more details.
     ///